@@ -2,7 +2,7 @@ import numpy as np
 import pandas as pd
 import pytest
 
-from src.synthesized_insight.metrics import (
+from synthesized_insight.metrics import (
     CramersV,
     DistanceCNCorrelation,
     DistanceNNCorrelation,
@@ -198,6 +198,11 @@ def test_r2_mcfadden_correlation():
 
     assert r2_mcfadden(sr_b, sr_a) is not None  # categorical, continuous -> not None
 
+    credit_df = pd.read_csv('tests/datasets/mini_credit.csv').sample(500)
+    assert r2_mcfadden(sr_a=credit_df['SeriousDlqin2yrs'], sr_b=credit_df['age']) is not None
+    assert r2_mcfadden(sr_a=credit_df['MonthlyIncome'], sr_b=credit_df['DebtRatio']) is None
+    assert r2_mcfadden(sr_a=credit_df['SeriousDlqin2yrs'], sr_b=credit_df['MonthlyIncome']) is not None
+
 
 def test_emd_distance_binned():
     a = pd.Series(np.random.normal(loc=10, scale=1.0, size=10000))
